pub struct TraceFrame { /* private fields */ }Expand description
Guard object representing an active traced function invocation.
Implementations
Sourceimpl TraceFrame
impl TraceFrame
Sourcepub fn enter(meta: FunctionMeta, values: Vec<ValueSlot>) -> TraceFrame
pub fn enter(meta: FunctionMeta, values: Vec<ValueSlot>) -> TraceFrame
Enters a traced function and records the corresponding event.
Sourcepub fn finish_return<T>(&mut self, result: &T)
pub fn finish_return<T>(&mut self, result: &T)
Records a successful function return.
Sourcepub fn finish_error(&mut self, message: impl Into<String>)
pub fn finish_error(&mut self, message: impl Into<String>)
Records an error or unwind outcome for the current frame.